Yet Another Portfolio Management Toolbox.

**Use at your own risk.**

## Features

* Data Augmentation
    * Concat different assets ohlcv
    * Concat different assets ticker
* Backtest
* Trading algorithms [full list](docs/algorithms.md)


## Contributing

TODOs (Check [ISSUES](https://github.com/dexhunter/mercurius/issues))

## Disclaimer

This project is based on OLPS[1] and PGPortfolio[2]. Many thanks to the authors.

[1] https://github.com/olps/olps
[2] https://github.com/zhengyaoJiang/PGPortfolio
